# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-06-16 10:30
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0004_merge_20200616_1011'),
        ('djangoldp_resource', '0003_resource_conversations'),
    ]

    operations = [
    ]



# Generated by Django 2.2.18 on 2021-05-25 08:22

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0011_auto_20210525_1018'),
    ]

    operations = [
        migrations.AlterField(
            model_name='keyword',
            name='name',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Keywords'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='img',
            field=models.URLField(blank=True, default='http://localhost:8000/media/defaultresource.png', null=True, verbose_name='Illustration'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='name',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Resource Title'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='type',
            name='name',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Resource type'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-04-26 16:45
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Keyword',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('name', models.CharField(max_length=50, verbose_name='Keywords')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
        migrations.CreateModel(
            name='Resource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('name', models.CharField(max_length=50, verbose_name='Resource Title')),
                ('shortdesc', models.TextField(blank=True, null=True)),
                ('longdesc', models.TextField(blank=True, null=True)),
                ('img', models.URLField(blank=True, null=True, verbose_name='Illustration')),
                ('document', models.URLField(blank=True, null=True, verbose_name='Document')),
                ('link', models.CharField(blank=True, max_length=150, null=True, verbose_name='Internet link')),
                ('keywords', models.ManyToManyField(blank=True, to='djangoldp_resource.Keyword')),
            ],
        ),
        migrations.CreateModel(
            name='Type',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('name', models.CharField(max_length=50, verbose_name='Resource type')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
        migrations.AddField(
            model_name='resource',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoldp_resource.Type', verbose_name='Resource type'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-05-05 15:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_conversation', '0002_auto_20190917_1056'),
        ('djangoldp_resource', '0002_auto_20200426_1902'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='conversations',
            field=models.ManyToManyField(blank=True, related_name='resources', to='djangoldp_conversation.Conversation'),
        ),
    ]



from djangoldp.permissions import LDPPermissions
from djangoldp_resource.filters import ResourceFilterBackend
from pprint import pprint


class ResourcePermissions(LDPPermissions):
    with_cache = False
    filter_backends = [ResourceFilterBackend]
    


# Generated by Django 2.2.28 on 2022-10-12 13:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0012_auto_20210525_1022'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resource',
            name='link',
            field=models.CharField(blank=True, max_length=2048, null=True, verbose_name='Internet link'),
        ),
    ]



# Generated by Django 2.2.18 on 2021-05-25 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0010_auto_20200923_1017'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='keyword',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='resource',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='type',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AddField(
            model_name='resource',
            name='creationDate',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-08-12 14:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0007_auto_20200709_1411'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resource',
            name='img',
            field=models.URLField(default='http://localhost:8000/media/defaultresource.png', verbose_name='Illustration'),
        ),
    ]



# Generated by Django 2.2.16 on 2020-09-23 10:17

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0009_auto_20200812_1459'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resource',
            name='circle',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='resources', to='djangoldp_circle.Circle'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djangoldp_resource.Type', verbose_name='Resource type'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-07-09 14:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0006_auto_20200617_1458'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='circle',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='resources', to='djangoldp_circle.Circle'),
        ),
        migrations.AlterField(
            model_name='keyword',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AlterField(
            model_name='type',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
    ]



from django.db.models import Q
from djangoldp.filters import LDPPermissionsFilterBackend

class ResourceFilterBackend(LDPPermissionsFilterBackend):
    
    def filter_queryset(self, request, queryset, view):
        # Test if this not an anonymous user
        if request.user.is_authenticated:
            # Exclude all resources with privates circles not believe to this user
            return queryset.exclude(
                Q(circle__status__iexact='private') &
                ~Q(circle__members__user=request.user)
            )
        else :
            # Exclude all resources with privates circles
            return queryset.exclude( Q( circle__status__iexact='private' ) )




from django.conf import settings
from django.db import models
from djangoldp_conversation.models import Conversation, Message
from djangoldp.models import Model
from djangoldp_circle.models import Circle
from django.contrib.auth import get_user_model
from djangoldp_resource.permissions import *


class Type (Model):
    name = models.CharField(max_length=50, null=True, blank=True, verbose_name="Resource type")

    class Meta(Model.Meta):
        anonymous_perms = ['view', 'add']
        rdf_type = 'sib:type'

    def __str__(self):
        return self.name


class Keyword (Model):
    name = models.CharField(max_length=50, null=True, blank=True, verbose_name="Keywords")

    class Meta(Model.Meta):
        anonymous_perms = ['view', 'add']
        rdf_type = 'sib:keyword'
 
    def __str__(self):
        return self.name


class Resource (Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True, on_delete=models.SET_NULL)
    name = models.CharField(max_length=50, verbose_name="Resource Title", null=True, blank=True)
    shortdesc = models.TextField(blank=True, null=True)
    longdesc = models.TextField(blank=True, null=True)
    keywords = models.ManyToManyField(Keyword, blank=True)
    type = models.ForeignKey(Type, blank=True, null=True,verbose_name="Resource type", on_delete=models.SET_NULL)
    img = models.URLField(default=settings.BASE_URL + "/media/defaultresource.png", verbose_name="Illustration", null=True, blank=True)
    document = models.URLField(blank=True, null=True, verbose_name="Document")
    link = models.CharField(max_length=2048, blank=True, null=True, verbose_name="Internet link")
    conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
    circle = models.ForeignKey(Circle, blank=True, null=True, related_name="resources", on_delete=models.SET_NULL)
    creationDate = models.DateTimeField(auto_now_add=True, blank=True, null=True)

    class Meta(Model.Meta):
        serializer_fields = ["@id", "name", "shortdesc", "longdesc", "type", "img", "document",\
                           "link", "keywords", "conversations", "circle"]
        auto_author = 'user'
        owner_field = 'user'
        container_path = 'resources/'
        rdf_type = 'hd:resource'
        anonymous_perms = ['view']
        owner_perms = ['inherit', 'change', 'control', 'delete']
        authenticated_perms = ['inherit', 'add']
        nested_fields = ['keywords', 'conversations', 'circle', 'type']
        permission_classes = [ResourcePermissions]
        
    def __str__(self):
        return self.name
